"""..."""

from aligo.core import *
from aligo.core.Config import *
from aligo.request import *
from aligo.response import *


class Video(BaseAligo):
    """..."""

    def _core_get_video_play_info(self, body: GetVideoPlayInfoRequest) -> GetVideoPlayInfoResponse:
        """..."""
        response = self._post(V2_DATABOX_GET_VIDEO_PLAY_INFO, body=body)
        return self._result(response, GetVideoPlayInfoResponse)

    def _core_get_video_preview_play_info(
            self,
            body: GetVideoPreviewPlayInfoRequest
    ) -> GetVideoPreviewPlayInfoResponse:
        """可获取m3u8链接"""
        response = self._post(V2_FILE_GET_VIDEO_PREVIEW_PLAY_INFO, body=body)
        return self._result(response, GetVideoPreviewPlayInfoResponse)



"""..."""
# 导包基本原则
# 1. 包内相对导入: from .DataClass import DataClass
# 2. 包外包导入: from aligo.dataobj import xxx
from dataclasses import dataclass

from .DataClass import DataClass


@dataclass
class AudioMeta(DataClass):
    """..."""
    bitrate: int = None
    duration: int = None
    sample_rate: int = None
    channels: int = None



"""..."""

from dataclasses import dataclass, field

from aligo.types import *
from aligo.types.Enum import *


@dataclass
class GetFileListRequest(DataClass):
    """..."""
    parent_file_id: str = 'root'
    drive_id: str = None
    starred: bool = field(default=None, repr=False)
    all: bool = field(default=False, repr=False)
    category: BaseFileCategory = field(default=None, repr=False)
    fields: GetFileListFields = field(default='*', repr=False)
    image_thumbnail_process: str = field(default='image/resize,w_400/format,jpeg', repr=False)
    image_url_process: str = field(default='image/resize,w_1920/format,jpeg', repr=False)
    limit: int = field(default=200, repr=False)
    marker: str = field(default=None, repr=False)
    order_by: GetFileListOrderBy = field(default='updated_at', repr=False)
    order_direction: OrderDirection = field(default='DESC', repr=False)
    status: str = field(default=None, repr=False)
    type: BaseFileType = field(default=None, repr=False)
    url_expire_sec: int = field(default=14400, repr=False)
    video_thumbnail_process: str = field(default='video/snapshot,t_0,f_jpg,ar_auto,w_800', repr=False)



"""..."""
from dataclasses import dataclass

from .MediaTransCodeTemplate import MediaTransCodeTemplate
from .Enum import MediaTranscodeStatus


@dataclass
class AudioTranscodeTemplate(MediaTransCodeTemplate):
    """..."""
    template_id: str = None
    status: MediaTranscodeStatus = None
    url: str = None



"""..."""

from aligo.core import *
from aligo.core.Config import *
from aligo.response import RewardSpaceResponse, UsersVipInfoResponse
from aligo.types import *


class User(BaseAligo):
    """..."""

    def get_user(self, f5: bool = False) -> BaseUser:
        """
        获取用户信息
        :param f5: [可选] 是否强制刷新
        :return: [BaseUser]
        """
        if self._user is None or f5:
            response = self._post(V2_USER_GET)
            # response.status_code == 200 or self._error_log_exit(response)
            # self._user = BaseUser(**response.json())
            self._user = self._result(response, BaseUser)
        return self._user

    def rewards_space(self, code: str):
        """
        获取奖励空间
        :param code: [必选] 奖励码
        :return: [RewardSpaceResponse]

        >>> from aligo import Aligo
        >>> ali = Aligo()
        >>> result = ali.rewards_space('12345678')
        >>> print(result)
        """
        response = self._post(V1_USERS_REWARDS, MEMBER_HOST, body={
            'code': code
        })
        return self._result(response, RewardSpaceResponse)

    def get_user_config(self) -> UserConfig:
        """获取用户配置信息"""
        response = self._post(ADRIVE_V1_USER_CONFIG_GET, body={})
        return self._result(response, UserConfig)

    def get_vip_info(self) -> UsersVipInfoResponse:
        """获取用户vip信息"""
        response = self._post(BUSINESS_V1_USERS_VIP_INFO, body={})
        return self._result(response, UsersVipInfoResponse)



"""..."""
import hashlib
import os
import shutil
from datetime import datetime
from typing import Callable
from typing import Dict, Union
from typing import Optional

from aligo.core import *
from aligo.request import GetFileListRequest, MoveFileToTrashRequest, CreateFolderRequest
from aligo.types import BaseFile


def utc_str_to_timestamp(utc: str) -> int:
    """'2022-04-16T11:07:03.276Z' -> timestamp"""
    return int(datetime.fromisoformat(utc[:-1]).timestamp()) + 28800


class SyncFolder(Core):
    """sync folder

    冲突：本地和云端冲突，一端是文件，另一端是文件夹，此种情况跳过，统一不处理

    三种同步模式：
        1. 双端同步
            差异文件保持最新；独有文件上传和下载，保持共有。

        2. 本地为主
            差异文件，本地为主；本地独有文件，上传；云端独有文件，忽略。

        3. 云端为主
            差异文件，云端为主；云端独有文件，下载；本地独有文件，忽略。
    """

    def sync_folder(
            self,
            local_folder: str,
            remote_folder: str,
            flag: Optional[bool] = None,
            file_filter: Callable[[Union[str, BaseFile]], bool] = lambda x: False,
            ignore_content: bool = False,
            follow_delete: bool = False,
            drive_id: str = None
    ):
        """
        sync folder
        :param local_folder: 本地文件夹路径
        :param remote_folder: 云端文件夹 file_id
        :param flag: 同步标志（类型），默认：None, 另外可选：True, False
            None：双端同步
            True：以本地为主
            False：以云端为主
        :param file_filter: 文件过滤函数，参数为 本地文件绝对路径 / 云端文件 BaseFile，返回值为 `True` 则过滤，可用于实现 只同步 特定文件 或 排除某些文件
        :param ignore_content: 是否忽略文件内容，默认：False
        :param follow_delete: 是否跟随删除，默认：False
        :param drive_id: 云端文件夹 drive_id
        :return:

        :Example:
        >>> from aligo import Aligo
        >>> ali = Aligo()
        >>> ali.sync_folder('<本地路径>', '<云端文件夹 file_id>')
        """
        if flag is None:
            self._auth.log.info('sync_folder: 双端同步')
        elif flag:
            self._auth.log.info('sync_folder: 本地为主')
        else:
            self._auth.log.info('sync_folder: 云端为主')

        if not os.path.exists(local_folder):
            self._auth.log.warning('本地文件夹不存在: %s', local_folder)
            return
        self.__sync_folder(local_folder, remote_folder, flag, file_filter, ignore_content, follow_delete, drive_id)

    def __sync_folder(
            self,
            local_folder: str,
            remote_folder: str,
            flag: Optional[bool],
            file_filter: Callable[[Union[str, BaseFile]], bool],
            ignore_content: bool,
            follow_delete: bool,
            drive_id: str):
        """..."""
        # 获取local_folder下的所有文件 # 转为 {文件名:文件路径} 字典模式
        local_files = {}
        for f in os.listdir(local_folder):
            local_file = os.path.join(local_folder, f)
            # 过滤文件只处理文件，跳过 文件夹
            if os.path.isfile(local_file) and file_filter(local_file):
                self._auth.log.debug(f'过滤本地文件 {local_file}')
                continue
            local_files[f] = local_file
        # 获取remote_folder下的所有文件 # 转为 {文件名:BaseFile对象} 字典模式
        remote_files: Dict[str, BaseFile] = {}
        for f in self._core_get_file_list(
                GetFileListRequest(remote_folder, drive_id=drive_id)
        ):
            remote_file = f.name
            if f.type == 'file' and file_filter(f):
                self._auth.log.debug(f'过滤云端文件 {remote_file}')
                continue
            remote_files[remote_file] = f

        if flag is None:
            self.__sync_all(
                drive_id, file_filter, flag, local_files, local_folder, remote_files, remote_folder, ignore_content,
                follow_delete)
        elif flag:
            self.__sync_local(
                drive_id, local_files, remote_files, remote_folder, flag, file_filter, local_folder, ignore_content,
                follow_delete)
        else:
            self.__sync_remote(drive_id, local_files, remote_files, local_folder, flag, file_filter, ignore_content,
                               follow_delete)

    def __sync_all(
            self, drive_id, file_filter, flag, local_files, local_folder, remote_files, remote_folder, ignore_content,
            follow_delete
    ):
        # 双端同步
        for f in list(local_files):
            # 在字典中获取并删除 local_file
            local_file = local_files.pop(f)
            # 文件夹则递归
            if os.path.isdir(local_file):
                # 判断云端是否存在
                if f in remote_files:
                    # 如果有，则判断是不是文件夹，不是就跳过
                    remote_file = remote_files.pop(f)
                    if remote_file.type == 'file':
                        # 跳过冲突
                        self._auth.log.warning(f'冲突：本地是文件夹，云端是文件，不处理 {f}')
                        continue
                else:
                    # 如果没有，则创建文件夹
                    self._auth.log.debug(f'本地是文件夹，云端不存在，创建云端文件夹，并递归 {f}')
                    remote_file = self._core_create_folder(
                        CreateFolderRequest(name=f, parent_file_id=remote_folder, drive_id=drive_id,
                                            check_name_mode='overwrite')
                    )
                self.__sync_folder(local_file, remote_file.file_id, flag, file_filter, ignore_content, follow_delete,
                                   drive_id)
                continue

            # 如果本地文件存在，且在云端也存在，则依次比较 size，sha1，时间戳
            if f in remote_files:
                # 在字典中获取并删除 remote_file
                remote_file = remote_files.pop(f)
                # 先判断文件类型
                if remote_file.type == 'folder':
                    # 没有主次端，不自动处理冲突
                    self._auth.log.warning(f'冲突：本地为文件，云端为文件夹，不处理 {f}')
                    continue

                # 获取 f 文件大小
                local_size = os.path.getsize(local_file)
                # 比较大小
                if local_size == remote_file.size:
                    # 跳过对比文件内容
                    if ignore_content:
                        self._auth.log.warning(f'忽略文件内容: 不处理 {f}')
                        continue

                    # 计算 f 文件 sha1
                    local_sha1 = self._core_sha1(local_file).lower()
                    # 如果sha1值相同，则跳过
                    if local_sha1 == remote_file.content_hash.lower():
                        self._auth.log.debug(f'文件 {f} 已存在，且sha1值相同，跳过')
                        continue
                # 否则对比时间戳，删除较旧文件，同步最新文件
                # 获取 f 文件的最后修改时间
                local_time = os.path.getmtime(local_file)
                local_time = int(local_time)
                # 获取云端文件的最后修改时间
                remote_time = remote_file.updated_at
                # 将UTC时间字符串转换为时间戳
                remote_time = utc_str_to_timestamp(remote_time)
                # 比较时间戳，删除较旧文件，同步最新文件
                if local_time > remote_time:
                    # 覆盖方式上传文件
                    self._auth.log.debug(f'本地文件较新，上传本地文件 {f}')
                    self.upload_file(file_path=local_file, parent_file_id=remote_folder, name=f,
                                     drive_id=drive_id, check_name_mode='overwrite')
                elif local_time < remote_time:
                    # 云端较新，删除本地，下载云端文件
                    self._auth.log.debug(f'云端较新，删除本地，下载云端文件 {f}')
                    os.remove(local_file)
                    self.download_files([remote_file], local_folder)
            else:
                # 不存在则直接上传
                self._auth.log.debug(f'云端不存在，上传本地文件 {f}')
                self.upload_file(file_path=local_file, parent_file_id=remote_folder, name=f,
                                 drive_id=drive_id, check_name_mode='overwrite')
        # 剩下的就是云端文件夹中有，本地文件夹中没有的文件，下载到本地
        if len(remote_files) != 0:
            self._auth.log.debug(f'本地不存在，下载云端文件 {len(remote_files)} {list(remote_files.keys())}')
            for remote_file in remote_files.values():
                if remote_file.type == 'file':
                    self.download_files([remote_file], local_folder)
                else:
                    self.download_folder(remote_file.file_id, local_folder)  # type: ignore

    def __sync_remote(self, drive_id, local_files, remote_files,
                      local_folder, flag, file_filter, ignore_content, follow_delete):
        # 以云端为主
        for f in list(remote_files):
            remote_file = remote_files.pop(f)
            # 文件夹则递归
            if remote_file.type == 'folder':
                # 判断本地是否存在
                if f in local_files:
                    # 如果有，则判断是否是文件夹，不是就忽略
                    local_file = local_files.pop(f)
                    if os.path.isfile(local_file):
                        # 跳过冲突
                        self._auth.log.warning(f'冲突：本地是文件，云端是文件夹，不处理 {f}')
                else:
                    # 如果没有，则创建本地文件夹
                    local_file = os.path.join(local_folder, f)
                    self._auth.log.debug(f'云端是文件夹，本地没有，创建文件夹，并递归 {local_file}')
                    if not os.path.exists(local_file):
                        os.mkdir(local_file)
                self.__sync_folder(local_file, remote_file.file_id, flag, file_filter, ignore_content, follow_delete,
                                   drive_id)
                continue

            # 如果云端文件存在，且在本地也存在，则依次比较 size，sha1，时间戳
            if f in local_files:
                local_file = local_files.pop(f)
                # 先判断文件类型
                if os.path.isdir(local_file):
                    # 云端为文件，本地却是文件夹，则递归删除文件夹，再下载文件
                    self._auth.log.debug('云端为文件，本地却是文件夹，则递归删除文件夹，再下载文件')
                    # 递归删除文件夹
                    shutil.rmtree(local_file)
                    # 下载文件
                    self.download_files([remote_file], local_folder)
                    continue

                # 获取 f 文件大小
                remote_size = remote_file.size
                # 比较大小
                if remote_size == os.path.getsize(local_file):
                    # 跳过对比文件内容
                    if ignore_content:
                        self._auth.log.warning(f'忽略文件内容: 不处理 {f}')
                        continue

                    # 计算 f 文件 sha1
                    local_sha1 = self._core_sha1(local_file).lower()
                    # 如果sha1值相同，则跳过
                    if local_sha1 == remote_file.content_hash.lower():
                        self._auth.log.debug(f'文件 {local_file} 已存在，且sha1值相同，跳过')
                        continue
                os.remove(local_file)
                self.download_files([remote_file], local_folder)
            else:
                # 不存在直接下载
                local_file = os.path.join(local_folder, f)
                self._auth.log.debug(f'本地不存在，下载云端文件 {local_file}')
                self.download_files([remote_file], local_folder)

        # 剩下的就是云端文件夹中没有，本地文件夹中有的文件，删除
        if follow_delete and len(local_files) != 0:
            self._auth.log.debug(f'云端不存在，本地存在 删除 {len(local_files)} {list(local_files.keys())}')
            for local_file in local_files.values():
                if os.path.isfile(local_file):
                    os.remove(local_file)
                else:
                    shutil.rmtree(local_file)

    def __sync_local(self, drive_id, local_files, remote_files,
                     remote_folder, flag, file_filter, local_folder, ignore_content, follow_delete):
        # 以本地为主
        for f in list(local_files):
            local_file = local_files.pop(f)
            # 文件夹则递归
            if os.path.isdir(local_file):
                # 判断云端是否存在
                if f in remote_files:
                    # 如果有，则判断是不是文件夹，不是就删除
                    remote_file = remote_files.pop(f)
                    if remote_file.type == 'file':
                        # 删除云端文件并创建文件夹
                        self._auth.log.warning(f'冲突：本地是文件夹，云端是文件，不处理 {f}')
                else:
                    # 如果没有，则创建文件夹
                    self._auth.log.debug(f'本地是文件夹，云端不存在，创建云端文件夹，并递归 {f}')
                    remote_file = self._core_create_folder(
                        CreateFolderRequest(name=f, parent_file_id=remote_folder, drive_id=drive_id,
                                            check_name_mode='overwrite')
                    )
                self.__sync_folder(local_file, remote_file.file_id, flag, file_filter, ignore_content, follow_delete,
                                   drive_id)
                continue

            # 如果本地文件存在，且在云端也存在，则依次比较 size，sha1，时间戳
            if f in remote_files:
                # 在字典中删除remote_file
                remote_file = remote_files.pop(f)
                # 先判断文件类型
                if remote_file.type == 'folder':
                    # 以本地文件夹为主，那只有删除云端文件夹，再上传本地文件
                    self._auth.log.debug(f'本地为文件，云端为文件夹，删除云端文件夹，并上传本地文件 {f}')
                    self._core_move_file_to_trash(
                        MoveFileToTrashRequest(file_id=remote_file.file_id, drive_id=drive_id)
                    )
                    self._auth.log.debug(f'上传本地文件 {f}')
                    self.upload_file(file_path=local_file, parent_file_id=remote_folder, name=f,
                                     drive_id=drive_id, check_name_mode='overwrite')
                    continue

                # 获取 f 文件大小
                local_size = os.path.getsize(local_file)
                # 比较大小
                if local_size == remote_file.size:
                    # 跳过对比文件内容
                    if ignore_content:
                        self._auth.log.warning(f'忽略文件内容: 不处理 {f}')
                        continue

                    # 计算 f 文件 sha1
                    local_sha1 = self._core_sha1(local_file).lower()
                    # 如果sha1值相同，则跳过
                    if local_sha1 == remote_file.content_hash.lower():
                        self._auth.log.debug(f'文件 {f} 已存在，且sha1值相同，跳过')
                        continue
                    else:
                        self.upload_file(file_path=local_file, parent_file_id=remote_folder, name=f,
                                         drive_id=drive_id, check_name_mode='overwrite')
                else:
                    self.upload_file(file_path=local_file, parent_file_id=remote_folder, name=f,
                                     drive_id=drive_id, check_name_mode='overwrite')
            else:
                # 不存在则直接上传
                self._auth.log.debug(f'云端不存在，上传本地文件 {f}')
                self.upload_file(file_path=local_file, parent_file_id=remote_folder, name=f,
                                 drive_id=drive_id, check_name_mode='overwrite')

        # 剩下的就是本地文件夹中没有，云端文件夹中有的文件，删除
        if follow_delete and len(remote_files) != 0:
            self._auth.log.debug(f'本地不存在，云端存在 删除 {len(remote_files)} {list(remote_files.keys())}')
            self.batch_move_to_trash([remote_file.file_id for remote_file in remote_files.values()])  # type: ignore

    @staticmethod
    def _core_sha1(param):
        """计算文件sha1"""
        sha1 = hashlib.sha1()
        with open(param, 'rb') as f:
            while True:
                data = f.read(8192)
                if not data:
                    break
                sha1.update(data)
        return sha1.hexdigest()



"""..."""
from dataclasses import dataclass, field
from typing import List

from aligo.types import DataClass


@dataclass
class BatchDownloadUrlRequest(DataClass):
    """
    /**
   * 过期时间
   * 默认值 : 900
   * 最小值 : 0
   * 最大值 : 14400
   */
    """
    file_id_list: List[str] = field(default_factory=list)
    expire_sec: int = 14400
    drive_id: str = None



"""..."""
from typing import List

from aligo.core import *
from aligo.core.Config import *
from aligo.request import AlbumListRequest, AlbumListFilesRequest
from aligo.types import ListAlbumItem, BaseAlbum, BaseFile
from aligo.types.Enum import *


class Album(Core):
    """..."""

    def list_albums(
            self, album_drive_id: str = None,
            order_by: GetShareLinkListOrderBy = 'created_at',
            order_direction: OrderDirection = 'DESC', drive_id=None
    ) -> List[ListAlbumItem]:
        """获取相册列表"""
        album_drive_id = album_drive_id or self.album_info.driveId
        drive_id = drive_id or self.default_drive_id
        body = AlbumListRequest(
            album_drive_id=album_drive_id, drive_id=drive_id,
            order_by=order_by, order_direction=order_direction
        )
        return list(self._core_list_album(body))

    def delete_album(self, album_id: str) -> bool:
        """删除 album"""
        response = self._post(ADRIVE_V1_ALBUM_DELETE, body={'album_id': album_id})
        return response.status_code == 200

    def create_album(self, name: str, description: str = None) -> BaseAlbum:
        """创建 album"""
        response = self._post(ADRIVE_V1_ALBUM_CREATE, body={
            'name': name,
            'description': description
        })
        return self._result(response, BaseAlbum)

    def get_album(self, album_id: str) -> BaseAlbum:
        """获取相册，通过 album_id"""
        response = self._post(ADRIVE_V1_ALBUM_GET, body={'album_id': album_id})
        return self._result(response, BaseAlbum)

    def add_files_to_album(self, album_id: str, files: List[BaseFile]) -> List[BaseFile]:
        response = self._post('/adrive/v1/album/add_files', body={
            'album_id': album_id,
            'drive_file_list': [{'drive_id': f.drive_id, 'file_id': f.file_id} for f in files]
        })
        return self._result(response, BaseFile, field='file_list')

    def list_album_files(self, album_id: str, order_direction: OrderDirection = 'DESC') -> List[BaseFile]:
        """获取指定相册文件"""
        body = AlbumListFilesRequest(album_id=album_id, order_direction=order_direction)
        result = self._core_list_album_files(body)
        return list(result)

    def rename_album(self, album_id: str, name: str):
        response = self._post(ADRIVE_V1_ALBUM_UPDATE, body={
            'album_id': album_id,
            'name': name
        })
        return self._result(response, BaseAlbum)



"""分享相关"""
import warnings
from typing import List, overload

from aligo.core import *
from aligo.request import *
from aligo.response import *
from aligo.types import *
from aligo.types.Enum import *


def _deprecation_warning(kwargs):
    if 'share_id' in kwargs:
        kwargs.pop('share_id')
        warnings.warn('share 相关方法已删除 `share_id` 参数，因为 share_token 已包含了 share_id 信息',
                      DeprecationWarning, stacklevel=3)


class Share(Core):
    """..."""

    def share_file(self,
                   file_id: str,
                   share_name: str = None,
                   share_pwd: str = None,
                   expiration: str = None,
                   drive_id: str = None,
                   description: str = None) -> CreateShareLinkResponse:
        """
        官方：分享文件
        :param file_id: [必选] 文件id
        :param share_name: [可选] 分享名称
        :param share_pwd: [可选] 分享密码，默认：None，表示无密码
        :param expiration: [可选] 有效期，utc时间字符串：YYYY-MM-DDTHH:mm:ss.SSSZ
        :param drive_id: [可选] 所属网盘id
        :param description: [可选] 描述
        :return: [CreateShareLinkResponse]

        用法示例：
        >>> from aligo import Aligo
        >>> ali = Aligo()
        >>> share = ali.share_file('<file1_id>', share_name='share_name', share_pwd='2020', expiration='2021-12-01T00:00:00.000Z', description='description')
        >>> print(share)
        """
        return self.share_files([file_id], share_name, share_pwd, expiration, drive_id, description)

    def share_files(self,
                    file_id_list: List[str],
                    share_name: str = None,
                    share_pwd: str = None,
                    expiration: str = None,
                    drive_id: str = None,
                    description: str = None) -> CreateShareLinkResponse:
        """
        官方：分享文件
        :param file_id_list: [必选] 文件id列表
        :param share_name: [可选] 分享名称
        :param share_pwd: [可选] 分享密码，默认：None，表示无密码
        :param expiration: [可选] 有效期，utc时间字符串：YYYY-MM-DDTHH:mm:ss.SSSZ
        :param drive_id: [可选] 所属网盘id
        :param description: [可选] 描述
        :return: [CreateShareLinkResponse]

        用法示例：
        >>> from aligo import Aligo
        >>> ali = Aligo()
        >>> share = ali.share_files(['<file1_id>','<file2_id>'], share_name='share_name', share_pwd='2020', expiration='2021-12-01T00:00:00.000Z', description='description')
        >>> print(share)
        """
        body = CreateShareLinkRequest(
            file_id_list=file_id_list,
            share_name=share_name,
            share_pwd=share_pwd,
            expiration=expiration,
            drive_id=drive_id,
            description=description,
        )
        return self._core_share_file(body)

    def update_share(self,
                     share_id: str,
                     share_pwd: str = None,
                     expiration: str = None,
                     description: str = None,
                     share_name: str = None) -> UpdateShareLinkResponse:
        """
        官方：更新分享
        :param share_id: [必选] 分享id
        :param share_pwd: [可选] 分享密码，默认：None，表示无密码
        :param expiration: [可选] 有效期，utc时间字符串：YYYY-MM-DDTHH:mm:ss.SSSZ
        :param description: [可选] 描述
        :param share_name: [可选] 分享名称
        :return: [UpdateShareLinkResponse]

        用法示例：
        >>> from aligo import Aligo
        >>> ali = Aligo()
        >>> old_share = ali.share_file('<file_id>', share_name='old share')
        >>> new_share = ali.update_share(old_share.share_id, share_name='new share')
        >>> print(new_share)
        """
        body = UpdateShareLinkRequest(
            share_id=share_id,
            share_pwd=share_pwd,
            expiration=expiration,
            description=description,
            share_name=share_name,
        )
        return self._core_update_share(body)

    def cancel_share(self, share_id: str) -> CancelShareLinkResponse:
        """
        官方：取消分享
        :param share_id: [必选] 分享id
        :return: [CancelShareLinkResponse]

        用法示例：
        >>> from aligo import Aligo
        >>> ali = Aligo()
        >>> share = ali.share_file('<file_id>')
        >>> cancel_share = ali.cancel_share(share.share_id)
        >>> print(cancel_share)
        """
        body = CancelShareLinkRequest(share_id=share_id)
        return self._core_cancel_share(body)

    def batch_cancel_share(self, share_id_list: List[str]) -> List[BatchSubResponse]:
        """
        官方：批量取消分享
        :param share_id_list: [必选] 分享id列表
        :return: [List[BatchSubResponse]]

        用法示例：
        >>> from aligo import Aligo
        >>> ali = Aligo()
        >>> share1 = ali.share_file('<file1_id>')
        >>> share2 = ali.share_file('<file2_id>')
        >>> # noinspection PyShadowingNames
        >>> share_id_list = [share1.share_id, share2.share_id]
        >>> cancel_share = ali.batch_cancel_share(share_id_list)
        >>> print(cancel_share)
        """
        body = BatchCancelShareRequest(share_id_list=share_id_list)
        result = self._core_batch_cancel_share(body)
        return list(result)

    def get_share_list(self,
                       order_by: GetShareLinkListOrderBy = 'created_at',
                       order_direction: OrderDirection = 'DESC',
                       include_canceled: bool = False) -> List[ShareLinkSchema]:
        """
        官方：获取分享列表
        :param order_by: [可选] 排序字段，默认：created_at
        :param order_direction: [可选] 排序方向，默认：DESC
        :param include_canceled: [可选] 是否包含已取消的分享，默认：False
        :return: [List[ShareLinkSchema]]

        用法示例：
        >>> from aligo import Aligo
        >>> ali = Aligo()
        >>> share_list = ali.get_share_list()
        >>> print(share_list)
        """
        body = GetShareLinkListRequest(
            creator=self.user_id,
            limit=100,
            order_by=order_by,
            order_direction=order_direction,
            include_canceled=include_canceled,
        )
        result = self._core_get_share_list(body)
        return list(result)

    # 处理其他人的分享
    def get_share_info(self, share_id: str) -> GetShareInfoResponse:
        """
        官方：获取分享信息
        :param share_id: [必选] 分享id
        :return: [GetShareInfoResponse]

        用法示例：
        >>> from aligo import Aligo
        >>> ali = Aligo()
        >>> share = ali.share_file('<file_id>')
        >>> share_info = ali.get_share_info(share.share_id)
        >>> print(share_info)
        """
        body = GetShareInfoRequest(share_id=share_id)
        return self._core_get_share_info(body)

    def get_share_token(self, share_id: str, share_pwd: str = '') -> GetShareTokenResponse:
        """
        官方：获取分享token
        :param share_id: [必选] 分享id
        :param share_pwd: [可选] 分享密码，默认：None，表示无密码
        :return: [GetShareTokenResponse]

        用法示例：
        >>> from aligo import Aligo
        >>> ali = Aligo()
        >>> share = ali.share_file('<file_id>')
        >>> share_token = ali.get_share_token(share.share_id)
        >>> print(share_token)
        """
        body = GetShareTokenRequest(share_id=share_id, share_pwd=share_pwd)
        return self._core_get_share_token(body)

    @overload
    def get_share_file_list(
            self,
            share_token: GetShareTokenResponse,
            parent_file_id: str = 'root',
            **kwargs
    ) -> List[BaseShareFile]:
        """
        官方：获取分享文件列表
        :param share_token: [必选] 分享token
        :param parent_file_id:
        :param kwargs: [可选] 其他参数
        :return: [List[BaseShareFile]]

        用法示例：
        >>> from aligo import Aligo
        >>> ali = Aligo()
        >>> share = ali.share_file('<file_id>')
        >>> # noinspection PyShadowingNames
        >>> share_token = ali.get_share_token(share.share_id)
        >>> share_file_list = ali.get_share_file_list(share_token)
        >>> print(share_file_list)
        """

    @overload
    def get_share_file_list(
            self,
            body: GetShareFileListRequest,
            share_token: GetShareTokenResponse
    ) -> List[BaseShareFile]:
        """
        官方：获取分享文件列表
        :param body: [必选] 请求体
        :param share_token: [必选] 分享token
        :return: [List[BaseShareFile]]

        用法示例：
        >>> from aligo import Aligo, GetShareFileListRequest
        >>> ali = Aligo()
        >>> share = ali.share_file('<file_id>')
        >>> # noinspection PyShadowingNames
        >>> share_token = ali.get_share_token(share.share_id)
        >>> # noinspection PyShadowingNames
        >>> body = GetShareFileListRequest(share_id=share_token.share_id)
        >>> share_file_list = ali.get_share_file_list(body=body, share_token=share_token)
        >>> print(share_file_list)
        """

    def get_share_file_list(
            self,
            share_token: GetShareTokenResponse = None,
            parent_file_id: str = 'root',
            body: GetShareFileListRequest = None,
            **kwargs
    ) -> List[BaseShareFile]:
        """get_share_file_list"""
        _deprecation_warning(kwargs)
        if body is None:
            body = GetShareFileListRequest(share_id=share_token.share_id, parent_file_id=parent_file_id, **kwargs)
        result = self._core_get_share_file_list(body, share_token)
        return list(result)

    @overload
    def get_share_file(
            self,
            file_id: str,
            share_token: GetShareTokenResponse,
            **kwargs
    ) -> BaseShareFile:
        """
        官方：获取分享文件
        :param file_id: [必选] 文件id
        :param share_token: [必选] 分享token
        :param kwargs: [可选] 其他参数
        :return: [BaseShareFile]

        用法示例：
        >>> from aligo import Aligo
        >>> ali = Aligo()
        >>> share = ali.share_file('<file_id>')
        >>> # noinspection PyShadowingNames
        >>> share_token = ali.get_share_token(share.share_id)
        >>> share_file = ali.get_share_file(share.file_id, share_token)
        >>> print(share_file)
        """

    @overload
    def get_share_file(self, body: GetShareFileRequest, share_token: GetShareTokenResponse) -> BaseShareFile:
        """
        官方：获取分享文件
        :param body: [必选] 请求体
        :param share_token: [必选] 分享token
        :return: [BaseShareFile]

        用法示例：
        >>> from aligo import Aligo, GetShareFileRequest
        >>> ali = Aligo()
        >>> share = ali.share_file('<file_id>')
        >>> # noinspection PyShadowingNames
        >>> share_token = ali.get_share_token(share.share_id)
        >>> # noinspection PyShadowingNames
        >>> body = GetShareFileRequest(share_id=share.share_id, file_id=share.file_id)
        >>> share_file = ali.get_share_file(body=body, share_token=share_token)
        >>> print(share_file)
        """

    def get_share_file(
            self,
            file_id: str = None,
            share_token: GetShareTokenResponse = None,
            body: GetShareFileRequest = None,
            **kwargs
    ) -> BaseShareFile:
        """get_share_file"""
        _deprecation_warning(kwargs)
        if body is None:
            body = GetShareFileRequest(share_id=share_token.share_id, file_id=file_id, **kwargs)
        return self._core_get_share_file(body, share_token)

    @overload
    def get_share_link_download_url(
            self,
            file_id: str,
            share_token: GetShareTokenResponse,
            **kwargs
    ) -> GetShareLinkDownloadUrlResponse:
        """
        官方：获取分享文件下载链接
        :param file_id: [必选] 文件id
        :param share_token: [必选] 分享token
        :param kwargs: [可选] 其他参数
        :return: [GetShareLinkDownloadUrlResponse]

        用法示例：
        >>> from aligo import Aligo
        >>> ali = Aligo()
        >>> share = ali.share_file('<file_id>')
        >>> # noinspection PyShadowingNames
        >>> share_token = ali.get_share_token(share.share_id)
        >>> share_link_download_url = ali.get_share_link_download_url(share.file_id, share_token)
        >>> print(share_link_download_url)
        """

    @overload
    def get_share_link_download_url(
            self,
            body: GetShareLinkDownloadUrlRequest,
            share_token: GetShareTokenResponse
    ) -> GetShareLinkDownloadUrlResponse:
        """
        官方：获取分享文件下载链接
        :param body: [必选] 请求体
        :param share_token: [必选] 分享token
        :return: [GetShareLinkDownloadUrlResponse]

        用法示例：
        >>> from aligo import Aligo, GetShareLinkDownloadUrlRequest
        >>> ali = Aligo()
        >>> share = ali.share_file('<file_id>')
        >>> # noinspection PyShadowingNames
        >>> share_token = ali.get_share_token(share.share_id)
        >>> # noinspection PyShadowingNames
        >>> body = GetShareLinkDownloadUrlRequest(share_id=share.share_id, file_id=share.file_id)
        >>> share_link_download_url = ali.get_share_link_download_url(body=body, share_token=share_token)
        >>> print(share_link_download_url)
        """

    def get_share_link_download_url(
            self,
            file_id: str = None,
            share_token: GetShareTokenResponse = None,
            body: GetShareLinkDownloadUrlRequest = None,
            **kwargs
    ) -> GetShareLinkDownloadUrlResponse:
        """get_share_link_download_url"""
        _deprecation_warning(kwargs)
        if body is None:
            body = GetShareLinkDownloadUrlRequest(share_id=share_token.share_id, file_id=file_id, **kwargs)
        return self._core_get_share_link_download_url(body, share_token)

    @overload
    def share_file_saveto_drive(
            self,
            file_id: str,
            share_token: GetShareTokenResponse,
            to_parent_file_id: str = 'root',
            to_drive_id: str = None,
            new_name: str = None,
            **kwargs
    ) -> ShareFileSaveToDriveResponse:
        """
        官方：保存分享文件到指定的网盘
        :param file_id: [必选] 文件id
        :param share_token: [必选] 分享token
        :param to_parent_file_id: [必选] 目标父文件夹id，默认为根目录
        :param to_drive_id: [可选] 目标网盘id，默认为当前网盘
        :param new_name: [可选] 新文件名
        :param kwargs: [可选] 其他参数
        :return: [ShareFileSaveToDriveResponse]

        用法示例：
        >>> from aligo import Aligo
        >>> ali = Aligo()
        >>> share = ali.share_file('<file_id>')
        >>> # noinspection PyShadowingNames
        >>> share_token = ali.get_share_token(share.share_id)
        >>> share_file_saveto_drive = ali.share_file_saveto_drive(share.file_id, share_token)
        >>> print(share_file_saveto_drive)
        """

    @overload
    def share_file_saveto_drive(
            self,
            body: ShareFileSaveToDriveRequest,
            share_token: GetShareTokenResponse
    ) -> ShareFileSaveToDriveResponse:
        """
        官方：保存分享文件到指定的网盘
        :param body: [必选] 请求体
        :param share_token: [必选] 分享token
        :return: [ShareFileSaveToDriveResponse]

        用法示例：
        >>> from aligo import Aligo, ShareFileSaveToDriveRequest
        >>> ali = Aligo()
        >>> share = ali.share_file('<file_id>')
        >>> # noinspection PyShadowingNames
        >>> share_token = ali.get_share_token(share.share_id)
        >>> # noinspection PyShadowingNames
        >>> body = ShareFileSaveToDriveRequest(share_id=share.share_id, file_id=share.file_id)
        >>> share_file_saveto_drive = ali.share_file_saveto_drive(body=body,share_token=share_token)
        >>> print(share_file_saveto_drive)
        """

    def share_file_saveto_drive(
            self,
            file_id: str = None,
            share_token: GetShareTokenResponse = None,
            to_parent_file_id: str = 'root',
            to_drive_id: str = None,
            new_name: str = None,
            body: ShareFileSaveToDriveRequest = None,
            **kwargs
    ) -> ShareFileSaveToDriveResponse:
        """share_file_saveto_drive"""
        _deprecation_warning(kwargs)
        if body is None:
            body = ShareFileSaveToDriveRequest(
                share_id=share_token.share_id,
                file_id=file_id,
                to_parent_file_id=to_parent_file_id,
                to_drive_id=to_drive_id,
                new_name=new_name,
                **kwargs
            )
        return self._core_share_file_saveto_drive(body, share_token)

    @overload
    def batch_share_file_saveto_drive(
            self,
            file_id_list: List[str],
            share_token: GetShareTokenResponse,
            to_parent_file_id: str = 'root',
            to_drive_id: str = None,
            **kwargs
    ) -> List[BatchShareFileSaveToDriveResponse]:
        """
        官方：批量保存分享文件到指定的网盘
        :param file_id_list: [必选] 文件id列表
        :param share_token: [必选] 分享token
        :param to_parent_file_id: [必选] 目标父文件夹id，默认为根目录
        :param to_drive_id: [可选] 目标网盘id，默认为当前网盘
        :param kwargs: [可选] 其他参数
        :return: [List[BatchShareFileSaveToDriveResponse]]

        用法示例：
        >>> from aligo import Aligo
        >>> ali = Aligo()
        >>> share = ali.share_file('<file_id>')
        >>> # noinspection PyShadowingNames
        >>> share_token = ali.get_share_token(share.share_id)
        >>> batch_share_file_saveto_drive = ali.batch_share_file_saveto_drive(share.file_id_list, share_token)
        >>> print(batch_share_file_saveto_drive[0].file_id)
        """

    @overload
    def batch_share_file_saveto_drive(
            self, body: BatchShareFileSaveToDriveRequest,
            share_token: GetShareTokenResponse
    ) -> List[BatchShareFileSaveToDriveResponse]:
        """
        官方：批量保存分享文件到指定的网盘
        :param body: [必选] 请求体
        :param share_token: [必选] 分享token
        :return: [List[BatchShareFileSaveToDriveResponse]]

        用法示例：
        >>> from aligo import Aligo, BatchShareFileSaveToDriveRequest
        >>> ali = Aligo()
        >>> share = ali.share_file('<file_id>')
        >>> # noinspection PyShadowingNames
        >>> share_token = ali.get_share_token(share.share_id)
        >>> # noinspection PyShadowingNames
        >>> body = BatchShareFileSaveToDriveRequest(share_id=share.share_id, file_id_list=share.file_id_list)
        >>> batch_share_file_saveto_drive = ali.batch_share_file_saveto_drive(body=body,share_token=share_token)
        >>> print(batch_share_file_saveto_drive[0].file_id)
        """

    def batch_share_file_saveto_drive(
            self,
            file_id_list: List[str] = None,
            share_token: GetShareTokenResponse = None,
            to_parent_file_id: str = 'root',
            auto_rename: bool = True,
            to_drive_id: str = None,
            body: BatchShareFileSaveToDriveRequest = None,
            **kwargs,
    ) -> List[BatchShareFileSaveToDriveResponse]:
        """batch_share_file_saveto_drive"""
        _deprecation_warning(kwargs)
        if body is None:
            body = BatchShareFileSaveToDriveRequest(
                share_id=share_token.share_id,
                file_id_list=file_id_list,
                to_parent_file_id=to_parent_file_id,
                auto_rename=auto_rename,
                to_drive_id=to_drive_id,
            )
        result = self._core_batch_share_file_saveto_drive(body, share_token)
        return list(result)

    def share_file_save_all_to_drive(
            self,
            share_token: GetShareTokenResponse,
            to_parent_file_id: str = 'root',
            parent_file_id: str = 'root',
            auto_rename: bool = True,
            to_drive_id: str = None,
            **kwargs,
    ) -> List[BatchShareFileSaveToDriveResponse]:
        """保存所有分享文件到云盘"""
        _deprecation_warning(kwargs)
        file_list = self.get_share_file_list(share_token, parent_file_id=parent_file_id)
        result = self.batch_share_file_saveto_drive(
            [file.file_id for file in file_list],
            share_token,
            to_parent_file_id=to_parent_file_id,
            to_drive_id=to_drive_id,
            auto_rename=auto_rename,
        )
        return result

    def search_share_files(self, keyword: str, share_token: GetShareTokenResponse,
                           order_by: SearchFileOrderBy = 'name', order_direction: OrderDirection = 'DESC',
                           body: SearchShareFileRequest = None, **kwargs) -> List[BaseShareFile]:
        """在分享中搜索文件"""
        _deprecation_warning(kwargs)
        if body is None:
            body = SearchShareFileRequest(share_id=share_token.share_id, keyword=keyword,
                                          order_by=f'{order_by} {order_direction}', **kwargs)
        result = self._core_search_share_files(body, share_token)
        return list(result)



"""自定义分享"""
import base64
import json
from typing import List, Dict

from aligo.core import *
from aligo.request import *
from aligo.types import *
from aligo.types.Enum import *


class CustomShare(Core):
    """..."""

    _ALIGO_SHARE_SCHEMA = 'aligo://'

    @staticmethod
    def __share_files_by_aligo(files: List[BaseFile]) -> List:
        """..."""
        result = []
        for file in files:
            result.append({
                'name': file.name,
                'content_hash': file.content_hash,
                'size': file.size,
                'url': file.download_url
            })
        return result

    @staticmethod
    def share_file_by_aligo(file: BaseFile) -> str:
        """
        自定义分享文件
        :param file: [BaseFile] 分享文件（BaseFile对象）
        :return: [str] 分享信息

        用法示例：
        >>> from aligo import Aligo
        >>> ali = Aligo()
        >>> # 获取文件列表
        >>> # noinspection PyShadowingNames
        >>> file = ali.get_file('<file_id>')
        >>> # noinspection PyShadowingNames
        >>> result = ali.share_file_by_aligo(file)
        >>> print(result)
        """
        result = CustomShare.__share_files_by_aligo([file])
        return CustomShare._ALIGO_SHARE_SCHEMA + base64.b64encode(json.dumps(result).encode()).decode()

    @staticmethod
    def share_files_by_aligo(files: List[BaseFile]) -> str:
        """
        自定义分享文件
        :param files: [List[BaseFile]] 分享文件列表（BaseFile对象列表）
        :return: [str] 分享信息

        用法示例：
        >>> from aligo import Aligo
        >>> ali = Aligo()
        >>> # 获取文件列表
        >>> # noinspection PyShadowingNames
        >>> files = ali.get_file_list(parent_file_id='<file_id>')
        >>> # noinspection PyShadowingNames
        >>> result = ali.share_files_by_aligo(files)
        >>> print(result)
        """
        result = CustomShare.__share_files_by_aligo(files)
        return CustomShare._ALIGO_SHARE_SCHEMA + base64.b64encode(json.dumps(result).encode()).decode()

    def __share_folder_by_aligo(self, parent_file_id: str, drive_id: str = None) -> List:
        """..."""
        result = []
        files = []
        # 1. 获取 parent_file_id 目录下文件列表
        for file in self._core_get_file_list(GetFileListRequest(parent_file_id=parent_file_id, drive_id=drive_id)):
            if file.type == 'file':
                # 2. 如果是文件, 添加到 files
                files.append(file)
                continue
            # 3. 否则是文件夹, 递归
            result.append([file.name, self.__share_folder_by_aligo(parent_file_id=file.file_id, drive_id=drive_id)])
        result.append(self.__share_files_by_aligo(files))
        return result

    def share_folder_by_aligo(self, parent_file_id: str, drive_id: str = None) -> str:
        """
        自定义分享文件夹
        :param parent_file_id: [str] 文件夹id
        :param drive_id: Optional[str] 文件夹所在的网盘id
        :return: [str] 分享信息

        用法示例：
        >>> from aligo import Aligo
        >>> ali = Aligo()
        >>> # noinspection PyShadowingNames
        >>> result = ali.share_folder_by_aligo('<file_id>')
        >>> print(result)
        """
        result = self.__share_folder_by_aligo(parent_file_id=parent_file_id, drive_id=drive_id)
        if parent_file_id != 'root':
            folder = self._core_get_file(GetFileRequest(file_id=parent_file_id))
            result = [[folder.name, result]]
        else:
            result = [['root', result]]
        return CustomShare._ALIGO_SHARE_SCHEMA + base64.b64encode(json.dumps(result).encode()).decode()

    def __save_files_by_aligo(self, data: str, parent_file_id: str = 'root',
                              check_name_mode: CheckNameMode = 'auto_rename',
                              drive_id: str = None):
        result = []

        # data 肯定是list, 内含 文件夹 list 或文件 dict
        for obj in data:

            if isinstance(obj, dict):
                x = self.create_by_hash(
                    name=obj['name'], content_hash=obj['content_hash'],
                    size=obj['size'], url=obj['url'], parent_file_id=parent_file_id,
                    check_name_mode=check_name_mode, drive_id=drive_id)
                result.append(x)
                continue

            if len(obj) > 0 and isinstance(obj[0], str):
                # 创建文件夹
                folder = self._core_create_folder(CreateFolderRequest(name=obj[0], parent_file_id=parent_file_id,
                                                                      drive_id=drive_id))
                x = self.__save_files_by_aligo(obj[1], parent_file_id=folder.file_id)
                result.append((folder, x))
                continue

            file: Dict
            for file in obj:
                x = self.create_by_hash(
                    name=file['name'], content_hash=file['content_hash'],
                    size=file['size'], url=file['url'], parent_file_id=parent_file_id,
                    check_name_mode=check_name_mode, drive_id=drive_id)
                result.append(x)

        return result

    def save_files_by_aligo(self, data: str, parent_file_id: str = 'root',
                            check_name_mode: CheckNameMode = 'auto_rename',
                            drive_id: str = None):
        """
        保存自定义分享文件
        :param data: [str] 分享信息
        :param parent_file_id: Optional[str] 文件夹id
        :param check_name_mode: [CheckNameMode] 文件重命名模式
        :param drive_id: [str] 文件夹所在的网盘id
        :return: [List] 保存结果

        用法示例：
        >>> from aligo import Aligo
        >>> ali = Aligo()
        >>> # noinspection PyShadowingNames
        >>> result = ali.save_files_by_aligo('<自定义分享信息>')
        >>> print(result)
        """
        if not data.startswith(self._ALIGO_SHARE_SCHEMA):
            self._auth.log.warning(f'这不是合法 aligo 分享信息: {data}')
            return

        data = data[8:]
        data = json.loads(base64.b64decode(data))

        result = self.__save_files_by_aligo(data, parent_file_id, check_name_mode, drive_id)
        return result



"""..."""
from dataclasses import dataclass, field

from .BaseFile import BaseFile
from .FieldsInfo import FieldsInfo


@dataclass
class ShareLinkBaseFile(BaseFile):
    """..."""
    mime_type: str = None
    mime_extension: str = None
    revision_id: str = None
    ex_fields_info: FieldsInfo = field(default=None, repr=False)



"""..."""

from .AimSearchResponse import AimSearchResponse
from .AlbumInfoResponse import AlbumInfoResponse
from .AlbumListResponse import AlbumListResponse
from .ArchiveStatusResponse import ArchiveStatusResponse
from .ArchiveUncompressResponse import ArchiveUncompressResponse
from .BatchDownloadUrlResponse import BatchDownloadUrlResponse
from .BatchShareFileSaveToDriveResponse import BatchShareFileSaveToDriveResponse
from .BatchSubResponse import BatchSubResponse
from .CancelShareLinkResponse import CancelShareLinkResponse
from .CopyFileResponse import CopyFileResponse
from .CreateFileResponse import CreateFileResponse
from .CreateShareLinkResponse import CreateShareLinkResponse
from .DuplicateListResponse import DuplicateListResponse, DuplicateItem, DuplicateFileInfo
from .GetAudioPlayInfoResponse import GetAudioPlayInfoResponse
from .GetDownloadUrlResponse import GetDownloadUrlResponse
from .GetFileListResponse import GetFileListResponse
from .GetFilePathResponse import GetFilePathResponse
from .GetOfficePreviewUrlResponse import GetOfficePreviewUrlResponse
from .GetPersonalInfoResponse import GetPersonalInfoResponse
from .GetRecycleBinListResponse import GetRecycleBinListResponse
from .GetShareFileListResponse import GetShareFileListResponse
from .GetShareInfoResponse import GetShareInfoResponse
from .GetShareLinkDownloadUrlResponse import GetShareLinkDownloadUrlResponse
from .GetShareLinkListResponse import GetShareLinkListResponse
from .GetShareTokenResponse import GetShareTokenResponse
from .GetStarredListResponse import GetStarredListResponse
from .GetUploadUrlResponse import GetUploadUrlResponse
from .GetVideoPlayInfoResponse import GetVideoPlayInfoResponse
from .GetVideoPreviewPlayInfoResponse import GetVideoPreviewPlayInfoResponse
from .ListMyDrivesResponse import ListMyDrivesResponse
from .ListResponse import ListResponse
from .ListToCleanResponse import ListToCleanResponse
from .MoveFileResponse import MoveFileResponse
from .MoveFileToTrashResponse import MoveFileToTrashResponse
from .RestoreFileResponse import RestoreFileResponse
from .RewardSpaceResponse import RewardSpaceResponse
from .SearchFileResponse import SearchFileResponse
from .SearchShareFileResponse import SearchShareFileResponse
from .ShareFileSaveToDriveResponse import ShareFileSaveToDriveResponse
from .ShareItemInfo import ShareItemInfo
from .ShareLinkExtractCodeResponse import ShareLinkExtractCodeResponse
from .TemplateResponse import TemplateResponse
from .UpdateShareLinkResponse import UpdateShareLinkResponse
from .UsersVipInfoResponse import UsersVipInfoResponse



"""..."""

from aligo.core import Core
from aligo.request import ArchiveUncompressRequest, ArchiveStatusRequest
from aligo.response import ArchiveUncompressResponse, ArchiveStatusResponse
from aligo.types.Enum import ArchiveType


class Compress(Core):
    """..."""

    def archive_uncompress(
            self, file_id: str,
            target_file_id: str = 'root',
            archive_type: ArchiveType = 'zip',
            drive_id: str = None,
            target_drive_id: str = None
    ) -> ArchiveUncompressResponse:
        """创建在线解压缩任务"""
        if target_drive_id is None:
            target_drive_id = self.default_drive_id
        body = ArchiveUncompressRequest(
            file_id, target_file_id, archive_type, drive_id, target_drive_id
        )
        return self._core_archive_uncompress(body)

    def archive_status(
            self,
            file_id: str,
            task_id: str,
            drive_id: str = None
    ) -> ArchiveStatusResponse:
        """..."""
        body = ArchiveStatusRequest(
            file_id, task_id, drive_id
        )
        return self._core_archive_status(body)



"""..."""
from dataclasses import dataclass, field
from typing import List

from aligo.types import DataClass


@dataclass
class BatchCancelShareRequest(DataClass):
    """..."""
    share_id_list: List[str] = field(default_factory=list)
